.. _change_detectors:

Change detectors
================

Base
----

.. currentmodule:: skchange.change_detectors.base

.. autosummary::
   :toctree: auto_generated/
   :template: class.rst

   BaseChangeDetector

Change detectors
----------------
.. currentmodule:: skchange.change_detectors

.. autosummary::
   :toctree: auto_generated/
   :template: class.rst

   MovingWindow
   PELT
   SeededBinarySegmentation
